==> estateplat-common-1.2.4-20220718.084844-1072-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSdmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:zx@gtmap.cn">zx</a>
 * @version 1.0, 2018-9-30
 * @description 不动产登记水电煤信息
 */
@Table(name = "BDC_SDMXX")
public class BdcSdmxx {
    @Id
    private String sdmxxid; //水电煤信息ID
    private String xmid;//项目id
    private String skhh;//水卡户号
    private String dkhh;//电卡户号
    private String rqkhh;//燃气卡户号
    private String dskh;//电视卡号
    private String sfghswk;//是否过户水务卡
    private String sfghrqk;//是否过户燃气卡
    private String sfghdsk;//是否过户电视卡
    private String sfghdfk;//是否过户电费卡
    private String sffsjf;//是否分时缴费
    private String yhzdkgxsfjb;//原户主代扣关系是否解绑
    private String sfsfdw;//水费收费单位
    private String dfsfdw;//电费收费单位
    private String rqsfdw;//燃气收费单位
    private String dssfdw;//广电卡收费单位(电视收费)

    private String dkghjg;//电卡过户验证结果（1：过户成功 0：过户失败 2：验证成功 3：验证失败）
    private String dkghmsg;//电卡过户响应消息
    private String skghmsg;//水卡过户响应消息
    private String qkghmsg;//燃气卡过户响应消息
    private String dkyhmc;//电卡用户名称
    private String skyhmc;//水卡用户名称
    private String qkyhmc;//气卡用户名称
    private String dkyddz;//电卡用电地址
    private String skysdz;//水卡用水地址
    private String qkyqdz;//气卡用气地址
    private String dkxhzmc;//电卡新户主名称
    private String skxhzmc;//水卡新户主名称
    private String qkxhzmc;//气卡新户主名称
    private String dkghzt;//电卡过户状态
    private String dkqfje;//电卡欠费金额
    private String skqfje;//水卡欠费金额
    private String qkqfje;//气卡欠费金额


    public String getSffsjf() {
        return sffsjf;
    }

    public void setSffsjf(String sffsjf) {
        this.sffsjf = sffsjf;
    }

    public String getYhzdkgxsfjb() {
        return yhzdkgxsfjb;
    }

    public void setYhzdkgxsfjb(String yhzdkgxsfjb) {
        this.yhzdkgxsfjb = yhzdkgxsfjb;
    }

    public String getSfsfdw() {
        return sfsfdw;
    }

    public void setSfsfdw(String sfsfdw) {
        this.sfsfdw = sfsfdw;
    }

    public String getDfsfdw() {
        return dfsfdw;
    }

    public void setDfsfdw(String dfsfdw) {
        this.dfsfdw = dfsfdw;
    }

    public String getRqsfdw() {
        return rqsfdw;
    }

    public void setRqsfdw(String rqsfdw) {
        this.rqsfdw = rqsfdw;
    }

    public String getDssfdw() {
        return dssfdw;
    }

    public void setDssfdw(String dssfdw) {
        this.dssfdw = dssfdw;
    }

    public String getSdmxxid() {
        return sdmxxid;
    }

    public void setSdmxxid(String sdmxxid) {
        this.sdmxxid = sdmxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSkhh() {
        return skhh;
    }

    public void setSkhh(String skhh) {
        this.skhh = skhh;
    }

    public String getDkhh() {
        return dkhh;
    }

    public void setDkhh(String dkhh) {
        this.dkhh = dkhh;
    }

    public String getRqkhh() {
        return rqkhh;
    }

    public void setRqkhh(String rqkhh) {
        this.rqkhh = rqkhh;
    }

    public String getSfghswk() {
        return sfghswk;
    }

    public void setSfghswk(String sfghswk) {
        this.sfghswk = sfghswk;
    }

    public String getSfghrqk() {
        return sfghrqk;
    }

    public void setSfghrqk(String sfghrqk) {
        this.sfghrqk = sfghrqk;
    }

    public String getSfghdsk() {
        return sfghdsk;
    }

    public void setSfghdsk(String sfghdsk) {
        this.sfghdsk = sfghdsk;
    }

    public String getDskh() {
        return dskh;
    }

    public void setDskh(String dskh) {
        this.dskh = dskh;
    }

    public String getSfghdfk() {
        return sfghdfk;
    }

    public void setSfghdfk(String sfghdfk) {
        this.sfghdfk = sfghdfk;
    }

    public String getDkghjg() {
        return dkghjg;
    }

    public void setDkghjg(String dkghjg) {
        this.dkghjg = dkghjg;
    }

    public String getDkghmsg() {
        return dkghmsg;
    }

    public void setDkghmsg(String dkghmsg) {
        this.dkghmsg = dkghmsg;
    }

    public String getDkyhmc() {
        return dkyhmc;
    }

    public void setDkyhmc(String dkyhmc) {
        this.dkyhmc = dkyhmc;
    }

    public String getDkyddz() {
        return dkyddz;
    }

    public void setDkyddz(String dkyddz) {
        this.dkyddz = dkyddz;
    }

    public String getDkxhzmc() {
        return dkxhzmc;
    }

    public void setDkxhzmc(String dkxhzmc) {
        this.dkxhzmc = dkxhzmc;
    }

    public String getDkghzt() {
        return dkghzt;
    }

    public void setDkghzt(String dkghzt) {
        this.dkghzt = dkghzt;
    }

    public String getDkqfje() {
        return dkqfje;
    }

    public void setDkqfje(String dkqfje) {
        this.dkqfje = dkqfje;
    }

    public String getSkghmsg() {
        return skghmsg;
    }

    public void setSkghmsg(String skghmsg) {
        this.skghmsg = skghmsg;
    }

    public String getQkghmsg() {
        return qkghmsg;
    }

    public void setQkghmsg(String qkghmsg) {
        this.qkghmsg = qkghmsg;
    }

    public String getSkyhmc() {
        return skyhmc;
    }

    public void setSkyhmc(String skyhmc) {
        this.skyhmc = skyhmc;
    }

    public String getSkxhzmc() {
        return skxhzmc;
    }

    public void setSkxhzmc(String skxhzmc) {
        this.skxhzmc = skxhzmc;
    }

    public String getQkxhzmc() {
        return qkxhzmc;
    }

    public void setQkxhzmc(String qkxhzmc) {
        this.qkxhzmc = qkxhzmc;
    }

    public String getSkqfje() {
        return skqfje;
    }

    public void setSkqfje(String skqfje) {
        this.skqfje = skqfje;
    }

    public String getQkyhmc() {
        return qkyhmc;
    }

    public void setQkyhmc(String qkyhmc) {
        this.qkyhmc = qkyhmc;
    }

    public String getQkyqdz() {
        return qkyqdz;
    }

    public void setQkyqdz(String qkyqdz) {
        this.qkyqdz = qkyqdz;
    }

    public String getSkysdz() {
        return skysdz;
    }

    public void setSkysdz(String skysdz) {
        this.skysdz = skysdz;
    }

    public String getQkqfje() {
        return qkqfje;
    }

    public void setQkqfje(String qkqfje) {
        this.qkqfje = qkqfje;
    }
}

==> estateplat-common-1.2.4-20220818.093634-1085-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSdmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:zx@gtmap.cn">zx</a>
 * @version 1.0, 2018-9-30
 * @description 不动产登记水电煤信息
 */
@Table(name = "BDC_SDMXX")
public class BdcSdmxx {
    @Id
    private String sdmxxid; //水电煤信息ID
    private String xmid;//项目id
    private String skhh;//水卡户号
    private String dkhh;//电卡户号
    private String rqkhh;//燃气卡户号
    private String dskh;//电视卡号
    private String sfghswk;//是否过户水务卡
    private String sfghrqk;//是否过户燃气卡
    private String sfghdsk;//是否过户电视卡
    private String sfghdfk;//是否过户电费卡
    private String sffsjf;//是否分时缴费
    private String yhzdkgxsfjb;//原户主代扣关系是否解绑
    private String sfsfdw;//水费收费单位
    private String dfsfdw;//电费收费单位
    private String rqsfdw;//燃气收费单位
    private String dssfdw;//广电卡收费单位(电视收费)

    private String dkghjg;//电卡过户验证结果（1：过户成功 0：过户失败 2：验证成功 3：验证失败）
    private String dkghmsg;//电卡过户响应消息
    private String skghmsg;//水卡过户响应消息
    private String qkghmsg;//燃气卡过户响应消息
    private String dkyhmc;//电卡用户名称
    private String skyhmc;//水卡用户名称
    private String qkyhmc;//气卡用户名称
    private String qkyhdh;//气卡用户电话
    private String dkyddz;//电卡用电地址
    private String skysdz;//水卡用水地址
    private String qkyqdz;//气卡用气地址
    private String dkxhzmc;//电卡新户主名称
    private String skxhzmc;//水卡新户主名称
    private String qkxhzmc;//气卡新户主名称
    private String dkghzt;//电卡过户状态
    private String qkghzt;//气卡过户状态
    private String dkqfje;//电卡欠费金额
    private String skqfje;//水卡欠费金额
    private String qkqfje;//气卡欠费金额


    public String getSffsjf() {
        return sffsjf;
    }

    public void setSffsjf(String sffsjf) {
        this.sffsjf = sffsjf;
    }

    public String getYhzdkgxsfjb() {
        return yhzdkgxsfjb;
    }

    public void setYhzdkgxsfjb(String yhzdkgxsfjb) {
        this.yhzdkgxsfjb = yhzdkgxsfjb;
    }

    public String getSfsfdw() {
        return sfsfdw;
    }

    public void setSfsfdw(String sfsfdw) {
        this.sfsfdw = sfsfdw;
    }

    public String getDfsfdw() {
        return dfsfdw;
    }

    public void setDfsfdw(String dfsfdw) {
        this.dfsfdw = dfsfdw;
    }

    public String getRqsfdw() {
        return rqsfdw;
    }

    public void setRqsfdw(String rqsfdw) {
        this.rqsfdw = rqsfdw;
    }

    public String getDssfdw() {
        return dssfdw;
    }

    public void setDssfdw(String dssfdw) {
        this.dssfdw = dssfdw;
    }

    public String getSdmxxid() {
        return sdmxxid;
    }

    public void setSdmxxid(String sdmxxid) {
        this.sdmxxid = sdmxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSkhh() {
        return skhh;
    }

    public void setSkhh(String skhh) {
        this.skhh = skhh;
    }

    public String getDkhh() {
        return dkhh;
    }

    public void setDkhh(String dkhh) {
        this.dkhh = dkhh;
    }

    public String getRqkhh() {
        return rqkhh;
    }

    public void setRqkhh(String rqkhh) {
        this.rqkhh = rqkhh;
    }

    public String getSfghswk() {
        return sfghswk;
    }

    public void setSfghswk(String sfghswk) {
        this.sfghswk = sfghswk;
    }

    public String getSfghrqk() {
        return sfghrqk;
    }

    public void setSfghrqk(String sfghrqk) {
        this.sfghrqk = sfghrqk;
    }

    public String getSfghdsk() {
        return sfghdsk;
    }

    public void setSfghdsk(String sfghdsk) {
        this.sfghdsk = sfghdsk;
    }

    public String getDskh() {
        return dskh;
    }

    public void setDskh(String dskh) {
        this.dskh = dskh;
    }

    public String getSfghdfk() {
        return sfghdfk;
    }

    public void setSfghdfk(String sfghdfk) {
        this.sfghdfk = sfghdfk;
    }

    public String getDkghjg() {
        return dkghjg;
    }

    public void setDkghjg(String dkghjg) {
        this.dkghjg = dkghjg;
    }

    public String getDkghmsg() {
        return dkghmsg;
    }

    public void setDkghmsg(String dkghmsg) {
        this.dkghmsg = dkghmsg;
    }

    public String getDkyhmc() {
        return dkyhmc;
    }

    public void setDkyhmc(String dkyhmc) {
        this.dkyhmc = dkyhmc;
    }

    public String getDkyddz() {
        return dkyddz;
    }

    public void setDkyddz(String dkyddz) {
        this.dkyddz = dkyddz;
    }

    public String getDkxhzmc() {
        return dkxhzmc;
    }

    public void setDkxhzmc(String dkxhzmc) {
        this.dkxhzmc = dkxhzmc;
    }

    public String getDkghzt() {
        return dkghzt;
    }

    public void setDkghzt(String dkghzt) {
        this.dkghzt = dkghzt;
    }

    public String getDkqfje() {
        return dkqfje;
    }

    public void setDkqfje(String dkqfje) {
        this.dkqfje = dkqfje;
    }

    public String getSkghmsg() {
        return skghmsg;
    }

    public void setSkghmsg(String skghmsg) {
        this.skghmsg = skghmsg;
    }

    public String getQkghmsg() {
        return qkghmsg;
    }

    public void setQkghmsg(String qkghmsg) {
        this.qkghmsg = qkghmsg;
    }

    public String getSkyhmc() {
        return skyhmc;
    }

    public void setSkyhmc(String skyhmc) {
        this.skyhmc = skyhmc;
    }

    public String getSkxhzmc() {
        return skxhzmc;
    }

    public void setSkxhzmc(String skxhzmc) {
        this.skxhzmc = skxhzmc;
    }

    public String getQkxhzmc() {
        return qkxhzmc;
    }

    public void setQkxhzmc(String qkxhzmc) {
        this.qkxhzmc = qkxhzmc;
    }

    public String getSkqfje() {
        return skqfje;
    }

    public void setSkqfje(String skqfje) {
        this.skqfje = skqfje;
    }

    public String getQkyhmc() {
        return qkyhmc;
    }

    public void setQkyhmc(String qkyhmc) {
        this.qkyhmc = qkyhmc;
    }

    public String getQkyqdz() {
        return qkyqdz;
    }

    public void setQkyqdz(String qkyqdz) {
        this.qkyqdz = qkyqdz;
    }

    public String getSkysdz() {
        return skysdz;
    }

    public void setSkysdz(String skysdz) {
        this.skysdz = skysdz;
    }

    public String getQkqfje() {
        return qkqfje;
    }

    public void setQkqfje(String qkqfje) {
        this.qkqfje = qkqfje;
    }

    public String getQkyhdh() {
        return qkyhdh;
    }

    public void setQkyhdh(String qkyhdh) {
        this.qkyhdh = qkyhdh;
    }

    public String getQkghzt() {
        return qkghzt;
    }

    public void setQkghzt(String qkghzt) {
        this.qkghzt = qkghzt;
    }
}
